==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/DataSourceRowExpansionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceRowExpansionChangedEventArgsDescription } from "./DataSourceRowExpansionChangedEventArgsDescription";
/**
 * @hidden
 */
export let DataSourceRowExpansionChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceRowExpansionChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a == null) {
                DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b(a);
            a.ad("DataSourceRowExpansionChangedEventArgs", () => new DataSourceRowExpansionChangedEventArgsDescription());
            a.ac("DataSourceRowExpansionChangedEventArgs", DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
        }
    }
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, 'DataSourceRowExpansionChangedEventArgsDescriptionMetadata');
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceRowExpansionChangedEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/DataSourceRowExpansionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceRowExpansionChangedEventArgsDescription } from "./DataSourceRowExpansionChangedEventArgsDescription";
/**
 * @hidden
 */
export let DataSourceRowExpansionChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceRowExpansionChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a == null) {
                DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceRowExpansionChangedEventArgsDescriptionMetadata.c(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            DataSourceRowExpansionChangedEventArgsDescriptionMetadata.b(a);
            a.ae("DataSourceRowExpansionChangedEventArgs", () => new DataSourceRowExpansionChangedEventArgsDescription());
            a.ad("DataSourceRowExpansionChangedEventArgs", DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a);
        }
    }
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataSourceRowExpansionChangedEventArgsDescriptionMetadata, 'DataSourceRowExpansionChangedEventArgsDescriptionMetadata');
    DataSourceRowExpansionChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceRowExpansionChangedEventArgsDescriptionMetadata;
})();
